import { latex_types } from "./symbol_types";

export default {
  "usepackage": { insertText: "usepackage{$1}", documentation: "usepackage", kind: latex_types.keyword },
  "newenvironment": { insertText: "newenvironment{${1:name}}[$2]{$3}{$0}", documentation: "newenvironment", kind: latex_types.keyword },
  "newcommand": { insertText: "newcommand{${1:name}}[$2]{$3}", documentation: "newcommand", kind: latex_types.keyword },
  "renewcommand": { insertText: "renewcommand{${1:name}}[$2]{$3}", documentation: "renewcommand", kind: latex_types.keyword },

  "DeclareMathOperator": { insertText: "DeclareMathOperator{${1:operatorcommand}}{${2:operatorname}}$0", detail: "Define in preamble!", documentation: "Defines a new math operator. Use the stared version for operators with limits.", kind: latex_types.keyword },
  "DeclareMathOperator*": { insertText: "DeclareMathOperator*{${1:operatorcommand}}{${2:operatorname}}$0", detail: "Define in preamble!", documentation: "Defines a new math operator with limits.", kind: latex_types.keyword },

  "today": { insertText: "today", documentation: "The current Date", kind: latex_types.symbol },
  "TeX": { insertText: "TeX", documentation: "The TeX symbol", kind: latex_types.symbol },
  "LaTeX": { insertText: "LaTeX", documentation: "The LaTeX symbol", kind: latex_types.symbol },
  "LaTeXe": { insertText: "LaTeXe", documentation: "The current LaTeX symbol", kind: latex_types.symbol },

  "newline": { insertText: "newline", documentation: "Starts a new line", kind: latex_types.keyword },
  "newpage": { insertText: "newpage", documentation: "Starts a new page", kind: latex_types.keyword },
  "linebreak": { insertText: "newpage[]", detail: "Optional Param: int 0-4.", documentation: "Suggests a line break to the LaTeX compiler. Optional parameter: int from 0 to 4, a value lower 4 may be ignored if it would look bad.", kind: latex_types.keyword },
  "nolinebreak": { insertText: "nolinebreak[]", detail: "Optional Param: int 0-4.", documentation: "Suggests no line break to the LaTeX compiler. Optional parameter: int from 0 to 4, a value lower 4 may be ignored if it would look bad.", kind: latex_types.keyword },
  "pagebreak": { insertText: "nolinebreak[]", detail: "Optional Param: int 0-4.", documentation: "Suggests a page break to the LaTeX compiler. Optional parameter: int from 0 to 4, a value lower 4 may be ignored if it would look bad.", kind: latex_types.keyword },
  "nopagebreak": { insertText: "nolinebreak[]", detail: "Optional Param: int 0-4.", documentation: "Suggests no page break to the LaTeX compiler. Optional parameter: int from 0 to 4, a value lower 4 may be ignored if it would look bad.", kind: latex_types.keyword },

  "section": { insertText: "section{$1}", documentation: "Section", kind: latex_types.keyword },
  "section*": { insertText: "section*{$1}", documentation: "Section", kind: latex_types.keyword },
  "subsection": { insertText: "subsection{$1}", documentation: "Sub Section", kind: latex_types.keyword },
  "subsection*": { insertText: "subsection*{$1}", documentation: "Sub Section", kind: latex_types.keyword },
  "subsubsection": { insertText: "subsubsection{$1}", documentation: "Sub Sub Section", kind: latex_types.keyword },
  "subsubsection*": { insertText: "subsubsection*{$1}", documentation: "Sub Sub Section", kind: latex_types.keyword },
  "paragraph": { insertText: "paragraph{$1}", documentation: "paragraph", kind: latex_types.keyword },
  "paragraph*": { insertText: "paragraph*{$1}", documentation: "paragraph", kind: latex_types.keyword },

  "label": { insertText: "label{$1}$0", documentation: "Label", kind: latex_types.keyword },
  "ref": { insertText: "ref{$1}$0", documentation: "Reference", kind: latex_types.keyword },
  "eqref": { insertText: "eqref{$1}$0", documentation: "Equation reference", kind: latex_types.keyword },
  "pageref": { insertText: "pageref{$1}$0", documentation: "Page reference", kind: latex_types.keyword },
  "index": { insertText: "index{$1}$0", documentation: "Creates a index Entrie", kind: latex_types.keyword },

  "emph": { insertText: "emph{$1}$0", documentation: "Emphasize Text", kind: latex_types.function },
  "texttt": { insertText: "texttt{$1}$0", documentation: "Typeset Text", kind: latex_types.function },
  "textit": { insertText: "textit{$1}$0", documentation: "Italic Text", kind: latex_types.function },
  "textbf": { insertText: "textbf{$1}$0", documentation: "Bold Text", kind: latex_types.function },
  "underline": { insertText: "underline{$1}$0", documentation: "Bold Text", kind: latex_types.function },

  // TODO: need a specific type in different environments!!!
  "centering": { insertText: "centering", documentation: "Centers the content of figure or minipage content", kind: latex_types.keyword },
  "caption": { insertText: "caption{$1}$0", documentation: "Figure description", kind: latex_types.function },

  "verb": { insertText: "verb{$1}$0", detail: "Do not use verbatim environment and the \\verb command within parameters of other commands.", documentation: "Environment content will be directly printed, as if typed on a typewriter, with all line breaks and spaces, without any LaTeX command being executed.", kind: latex_types.environment },
  "verb*": { insertText: "verb*{$1}$0", detail: "Do not use verbatim environment and the \\verb command within parameters of other commands.", documentation: "Environment content will be directly printed, as if typed on a typewriter, with all line breaks and spaces, without any LaTeX command being executed. The additional * lets spaces be printed visible.", kind: latex_types.environment },

  "ldots": { insertText: "ldots", documentation: "3 lower dots", kind: latex_types.symbol },

};
